Imports System
Imports System.Collections.Generic
Imports System.ComponentModel
Imports System.Data
Imports System.Drawing
Imports System.Text
Imports System.Windows.Forms
Imports Infragistics.Win
Imports Infragistics.Win.UltraWinSchedule
Imports Infragistics.Win.UltraWinEditors
Imports Infragistics.Win.UltraWinSchedule.MonthViewMulti
Imports nsMVS = Infragistics.Win.UltraWinSchedule.MonthViewSingle
Imports nsDayView = Infragistics.Win.UltraWinSchedule.DayView
Imports Infragistics.Win.UltraWinListView
Imports System.Globalization

Public Class frmMain
    Private calendarInfo As UltraCalendarInfo = Nothing
    Private calendarLook As UltraCalendarLook = Nothing

    Public Sub New()

        Me.InitializeComponent()
        Me.InitializeUI()

    End Sub

    Private Sub InitializeUI()


        '  Set tooltips for the controls so that the user can get a clearer
        '  picture of how the event arguments properties work.
        Me.SetupToolTips()

        '  Create an UltraCalendarInfo/UltraCalendarLook
        Me.calendarInfo = New UltraCalendarInfo(Me.components)
        Me.calendarLook = New UltraCalendarLook(Me.components)

        '  Synchronize the UltraCalendarInfo/UltraCalendarLook for each control
        Me.dayView.CalendarInfo = Me.calendarInfo
        Me.weekView.CalendarInfo = Me.calendarInfo
        Me.monthViewSingle.CalendarInfo = Me.calendarInfo
        Me.monthViewMulti.CalendarInfo = Me.calendarInfo
        Me.timeLineView.CalendarInfo = Me.calendarInfo

        Me.dayView.CalendarLook = Me.calendarLook
        Me.weekView.CalendarLook = Me.calendarLook
        Me.monthViewSingle.CalendarLook = Me.calendarLook
        Me.monthViewMulti.CalendarLook = Me.calendarLook
        Me.timeLineView.CalendarLook = Me.calendarLook

        '  Use the Office2007 ViewStyle
        calendarLook.ViewStyle = ViewStyle.Office2007

        '  Show multiple owners
        Me.calendarInfo.Owners.UnassignedOwner.Visible = False
        Dim owner2 As Owner = Me.calendarInfo.Owners.Add("OneCalendar")
        Dim owner1 As Owner = Me.calendarInfo.Owners.Add("AnotherCalendar")
        Me.dayView.GroupingStyle = DayViewGroupingStyle.OwnerWithinDate
        Me.weekView.OwnerDisplayStyle = OwnerDisplayStyle.Separate
        Me.weekView.MaximumOwnersInView = 2
        Me.monthViewSingle.OwnerDisplayStyle = OwnerDisplayStyle.Separate
        Me.monthViewSingle.MaximumOwnersInView = 2
        Me.timeLineView.OwnerGroupingStyle = TimelineViewOwnerGroupingStyle.Separate
        Me.timeLineView.MaximumOwnersInView = 2

        '  Add some appointments for each owner
        Me.AddAppointments(100, 5, owner1)
        Me.AddAppointments(100, 5, owner2)

        '  Handle events       
        AddHandler Me.chkCancel.CheckedChanged, AddressOf Me.OnCheckedChanged
        AddHandler Me.chkDragDrop.CheckedChanged, AddressOf Me.OnCheckedChanged

        '  Populate the 'phase' ComboBox, so different phases of
        '  the events can be canceled
        Me.cboPhase.DropDownStyle = ComboBoxStyle.DropDownList
        Me.cboPhase.Items.Add("All")
        Me.cboPhase.Items.Add("Beginning")
        Me.cboPhase.Items.Add("Moving")
        Me.cboPhase.Items.Add("Ending")
        Me.cboPhase.SelectedIndex = 0

        '  Handle the AppointmentsDragging, AppointmentsDragDrop, AppointmentResizing,
        '  and AppointmentResized event for the DayView, WeekView, and MonthViewSingle
        '  controls. Note that since the events are defined in a base class common to
        '  each of those controls, the handlers can be shared.
        AddHandler Me.dayView.AppointmentsDragging, AddressOf OnAppointmentsDragging
        AddHandler Me.dayView.AppointmentsDragDrop, AddressOf OnAppointmentsDragDrop
        AddHandler Me.dayView.AppointmentResizing, AddressOf OnAppointmentsResizing
        AddHandler Me.dayView.AppointmentResized, AddressOf OnAppointmentsResized

        AddHandler Me.weekView.AppointmentsDragging, AddressOf OnAppointmentsDragging
        AddHandler Me.weekView.AppointmentsDragDrop, AddressOf OnAppointmentsDragDrop
        AddHandler Me.weekView.AppointmentResizing, AddressOf OnAppointmentsResizing
        AddHandler Me.weekView.AppointmentResized, AddressOf OnAppointmentsResized

        AddHandler Me.monthViewSingle.AppointmentsDragging, AddressOf OnAppointmentsDragging
        AddHandler Me.monthViewSingle.AppointmentsDragDrop, AddressOf OnAppointmentsDragDrop
        AddHandler Me.monthViewSingle.AppointmentResizing, AddressOf OnAppointmentsResizing
        AddHandler Me.monthViewSingle.AppointmentResized, AddressOf OnAppointmentsResized

        AddHandler Me.timeLineView.AppointmentsDragging, AddressOf OnAppointmentsDragging
        AddHandler Me.timeLineView.AppointmentsDragDrop, AddressOf OnAppointmentsDragDrop
        AddHandler Me.timeLineView.AppointmentResizing, AddressOf OnAppointmentsResizing
        AddHandler Me.timeLineView.AppointmentResized, AddressOf OnAppointmentsResized

        '  Reduce VisibleWeeks in MonthViewSingle to see more activity
        Me.monthViewSingle.VisibleWeeks = 3

        ' Add a DateInterval to the AdditionalIntervals collection to display the Date above the Primary Intervals
        Me.timeLineView.AdditionalIntervals.Add(New DateInterval())

        '  Set up the UltraListView to be a drop target, to demonstrate how to
        '  drag appointments to a different control via the .NET drag/drop model.
        Me.lvwDropTarget.Enabled = False
        Me.lvwDropTarget.ViewSettingsDetails.AutoFitColumns = AutoFitColumns.ResizeAllColumns
        Me.lvwDropTarget.ViewSettingsDetails.ColumnAutoSizeMode = ColumnAutoSizeMode.VisibleItemsAndHeader
        Me.lvwDropTarget.AllowDrop = True
        Me.lvwDropTarget.View = UltraListViewStyle.Details
        AddHandler Me.lvwDropTarget.DragOver, AddressOf Me.listView_DragOver
        AddHandler Me.lvwDropTarget.DragDrop, AddressOf Me.listView_DragDrop

        Me.lvwDropTarget.MainColumn.Text = "Subject"

        Dim colStartDateTime As UltraListViewSubItemColumn = Me.lvwDropTarget.SubItemColumns.Add("StartDateTime")
        colStartDateTime.DataType = GetType(DateTime)
        colStartDateTime.Format = CultureInfo.CurrentCulture.DateTimeFormat.UniversalSortableDateTimePattern

        Dim colEndDateTime As UltraListViewSubItemColumn = Me.lvwDropTarget.SubItemColumns.Add("EndDateTime")
        colEndDateTime.DataType = GetType(DateTime)
        colEndDateTime.Format = CultureInfo.CurrentCulture.DateTimeFormat.UniversalSortableDateTimePattern

        Dim colOwnerKey As UltraListViewSubItemColumn = Me.lvwDropTarget.SubItemColumns.Add("Owner")
        colOwnerKey.DataType = GetType(String)

        Dim colWasCopied As UltraListViewSubItemColumn = Me.lvwDropTarget.SubItemColumns.Add("Copied")
        colWasCopied.DataType = GetType(Boolean)

        Dim checkEditor As New CheckEditor()
        colWasCopied.Editor = CheckEditor
        CheckEditor.CheckAlign = ContentAlignment.MiddleCenter
    End Sub

    Private Sub SetupToolTips()

        Dim toolTipText As String = String.Empty

        '  chkAllowCopy
        toolTipText = "Check to allow copies of the selected appointments to be made by pressing the Control key when a drag operation is in progress."
        Me.toolTip1.SetToolTip(Me.chkAllowCopy, toolTipText)

        '  chkAllowXOwnerDrag
        toolTipText = "Check to allow ownership of the appointments to be transferred via drag/drop. When checked, appointments can be dragged from one Owner to another, otherwise this action is prohibited."
        Me.toolTip1.SetToolTip(Me.chkAllowXOwnerDrag, toolTipText)

        '  chkCancel
        toolTipText = "Check to prevent the appointment(s) from being resized or dragged. When checked, the AppointmentsDragging/AppointmentsResizing event is canceled."
        Me.toolTip1.SetToolTip(Me.chkCancel, toolTipText)

        '  chkClearSelection
        toolTipText = "Check to clear the SelectedAppointments collection after a drag operation is completed."
        Me.toolTip1.SetToolTip(Me.chkClearSelection, toolTipText)

        '  chkDragDrop
        toolTipText = "Check to prevent the default appointment dragging behavior, and instead initiate a standard .NET drag/drop operation, whereby appointments can be dragged to a different control. When checked, appointments can be dragged to the UltraListView control at the bottom of the form."
        Me.toolTip1.SetToolTip(Me.chkDragDrop, toolTipText)

        '  chkEnterEditMode
        toolTipText = "Check to cause edit mode to be entered on an appointment immediately after it is resized."
        Me.toolTip1.SetToolTip(Me.chkEnterEditMode, toolTipText)

        '  cboPhase
        toolTipText = "Select an item from the list to change which phase of the AppointmentsDragging/AppointmentsResizing event is canceled, i.e., the Beginning, Moving, or Ending phase."
        Me.toolTip1.SetToolTip(Me.cboPhase, toolTipText)
    End Sub

    Private Sub AddAppointments(ByVal count As Int32, ByVal density As Int32, ByVal owner As Owner)

        Dim rangeStart As DateTime = DateTime.Today.AddDays((count / (density * 2)) * -1)
        Dim rangeEnd As DateTime = DateTime.Today.AddDays((count / (density * 2)))
        Dim theDate As DateTime = rangeStart

        Dim rand As New Random()

        While (theDate <= rangeEnd)

            Dim i As Int32 = 0
            For i = 0 To density

                Dim start As Int32 = rand.Next(540, 1020)
                Dim duration As Int32 = rand.Next(15, 240)
                Dim temp As DateTime = theDate.Date.AddMinutes(start)

                Dim appointment As New Appointment(temp, temp.AddMinutes(duration))

                If (i = 3) Then
                    Appointment.AllDayEvent = True
                    Appointment.Subject = String.Format("AllDay {0}", temp.ToShortDateString())

                Else
                    Appointment.Subject = String.Format("Appointment {0}", temp.ToShortTimeString())

                    appointment.OwnerKey = IIf(Not owner Is Nothing, owner.Key, String.Empty)

                    Me.calendarInfo.Appointments.Add(Appointment)
                End If
            Next


            theDate = theDate.AddDays(1)

        End While



    End Sub

    Private Sub OnCheckedChanged(ByVal sender As Object, ByVal e As EventArgs)

        Dim checkBox As CheckBox = sender

        '  Enable the ListView when this checkbox is checked, so
        '  appointments can be dragged to it.
        If (sender Is Me.chkDragDrop) Then
            Me.lvwDropTarget.Enabled = checkBox.Checked
        ElseIf (sender Is Me.chkCancel) Then
            '  Enable the 'phase' ComboBox when this checkbox is checked, so
            '  different phases of the before events can be canceled.
            Me.cboPhase.Enabled = checkBox.Checked
        End If
    End Sub

    Private Sub OnAppointmentsDragging(ByVal sender As Object, ByVal e As AppointmentsDraggingEventArgs)

        Dim control As ControlWithActivityBase = sender

        '  Allow/disallow appointment copying based on the state
        '  of the 'AllowCopy' checkbox.
        e.AllowCopy = Me.chkAllowCopy.Checked

        '  Allow/disallow changing appointment ownership based on the state
        '  of the 'AllowOwnerChange' checkbox.
        e.AllowOwnerChange = Me.chkAllowXOwnerDrag.Checked

        '  If the 'Cancel' checkbox is checked, and the phase of this event
        '  matches the one selected in the ComboBox, cancel the event.
        If (Me.chkCancel.Checked) Then

            If (String.Equals(Me.cboPhase.Text, "All") = False) Then

                Dim phase As AppointmentDragPhase = System.Enum.Parse(GetType(AppointmentDragPhase), Me.cboPhase.Text)
                e.Cancel = (e.Phase = phase)

            Else
                e.Cancel = True
            End If

        Else
            '  If this is the 'Beginning' phase of the event, and the '.NET DragDrop'
            '  checkbox is checked, initiate a .NET drag/drop operation by calling the
            '  control's DoDragDrop method, passing in the event arguments instance.
            '  See 'listView_DragDrop' method for the code that handles the drop.
            If (e.Phase = AppointmentDragPhase.Beginning AndAlso Me.chkDragDrop.Checked) Then

                e.Cancel = True
                control.DoDragDrop(e, DragDropEffects.All)
                System.Windows.Forms.Cursor.Current = Cursors.Default
            End If
        End If

    End Sub

    Private Sub OnAppointmentsDragDrop(ByVal sender As Object, ByVal e As AppointmentsDragDropEventArgs)
        '  By default, the appointment selection is cleared when ownership
        '  of the appointments changes. Setting 'ClearSelectedAppointments'
        '  to false prevents this from happening.
        e.ClearSelectedAppointments = Me.chkClearSelection.Checked
    End Sub

    Private Sub OnAppointmentsResizing(ByVal sender As Object, ByVal e As AppointmentResizingEventArgs)

        '  If the 'Cancel' checkbox is checked, and the phase of this event
        '  matches the one selected in the ComboBox, cancel the event.
        If (Me.chkCancel.Checked) Then

            If (String.Equals(Me.cboPhase.Text, "All") = False) Then

                Dim phase As AppointmentDragPhase = System.Enum.Parse(GetType(AppointmentDragPhase), Me.cboPhase.Text)
                e.Cancel = (e.Phase = phase)
            Else
                e.Cancel = True
            End If
        End If

    End Sub

    Private Sub OnAppointmentsResized(ByVal sender As Object, ByVal e As AppointmentResizedEventArgs)

        '  MS Outlook enters edit mode on an appointment after a resize
        '  operation is completed; set the 'EnterEditMode' property of the
        '  event arguments to true to emulate this behavior.
        e.EnterEditMode = Me.chkEnterEditMode.Checked
    End Sub

    Private Sub listView_DragOver(ByVal sender As Object, ByVal e As DragEventArgs)
        e.Effect = DragDropEffects.All
    End Sub

    Private Sub listView_DragDrop(ByVal sender As Object, ByVal e As DragEventArgs)

        Dim listView As UltraListView = sender

        Dim data As IDataObject = e.Data

        If (Not data Is Nothing AndAlso data.GetDataPresent(GetType(AppointmentsDraggingEventArgs))) Then

            '  Get the data that was passed via the DoDragDrop method.
            Dim args As AppointmentsDraggingEventArgs = data.GetData(GetType(AppointmentsDraggingEventArgs))

            '  Get the ReadOnlyAppointmentsCollection instance off the data that
            '  was passed via the DoDragDrop method.
            Dim appointments As ReadOnlyAppointmentsCollection = args.Appointments

            '  Clear previous entries
            listView.Items.Clear()

            '  Create an UltraListViewItem for each appointment that was dragged,
            '  and add it to a generic list
            Dim items As List(Of UltraListViewItem) = New List(Of UltraListViewItem)(appointments.Count)
            Dim appointment As Appointment
            For Each appointment In appointments

                Dim subItems As New List(Of Object)(4)
                subItems.Add(appointment.StartDateTime)
                subItems.Add(appointment.EndDateTime)
                subItems.Add(appointment.OwnerKey)
                subItems.Add(args.HasCopies)

                Dim item As New UltraListViewItem(appointment.Subject, subItems.ToArray())
                item.Tag = appointment

                items.Add(item)
            Next

            '  Populate the Items collection with the item list
            listView.Items.AddRange(items.ToArray())
        End If
    End Sub
End Class
